@@ -3,8 +3,11 @@ Main interface for sagemaker service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.sagemaker import (
+
+    from mypy_boto3_sagemaker import SageMakerClient
+    from mypy_boto3_sagemaker.paginator import (
         ListAlgorithmsPaginator,
         ListAppsPaginator,
         ListAutoMLJobsPaginator,
@@ -73,6 +76,7 @@ Usage::
     list_user_profiles_paginator: ListUserProfilesPaginator = client.get_paginator("list_user_profiles")
     list_workteams_paginator: ListWorkteamsPaginator = client.get_paginator("list_workteams")
     search_paginator: SearchPaginator = client.get_paginator("search")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
@@ -160,7 +164,7 @@ __all__ = (
 
 class ListAlgorithmsPaginator(Boto3Paginator):
     """
-    [Paginator.ListAlgorithms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListAlgorithms)
+    [Paginator.ListAlgorithms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListAlgorithms)
     """
 
     def paginate(
@@ -173,13 +177,13 @@ class ListAlgorithmsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAlgorithmsOutputTypeDef]:
         """
-        [ListAlgorithms.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListAlgorithms.paginate)
+        [ListAlgorithms.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListAlgorithms.paginate)
         """
 
 
 class ListAppsPaginator(Boto3Paginator):
     """
-    [Paginator.ListApps documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListApps)
+    [Paginator.ListApps documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListApps)
     """
 
     def paginate(
@@ -191,13 +195,13 @@ class ListAppsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAppsResponseTypeDef]:
         """
-        [ListApps.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListApps.paginate)
+        [ListApps.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListApps.paginate)
         """
 
 
 class ListAutoMLJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListAutoMLJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListAutoMLJobs)
+    [Paginator.ListAutoMLJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListAutoMLJobs)
     """
 
     def paginate(
@@ -213,13 +217,13 @@ class ListAutoMLJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAutoMLJobsResponseTypeDef]:
         """
-        [ListAutoMLJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListAutoMLJobs.paginate)
+        [ListAutoMLJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListAutoMLJobs.paginate)
         """
 
 
 class ListCandidatesForAutoMLJobPaginator(Boto3Paginator):
     """
-    [Paginator.ListCandidatesForAutoMLJob documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListCandidatesForAutoMLJob)
+    [Paginator.ListCandidatesForAutoMLJob documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListCandidatesForAutoMLJob)
     """
 
     def paginate(
@@ -232,13 +236,13 @@ class ListCandidatesForAutoMLJobPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListCandidatesForAutoMLJobResponseTypeDef]:
         """
-        [ListCandidatesForAutoMLJob.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListCandidatesForAutoMLJob.paginate)
+        [ListCandidatesForAutoMLJob.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListCandidatesForAutoMLJob.paginate)
         """
 
 
 class ListCodeRepositoriesPaginator(Boto3Paginator):
     """
-    [Paginator.ListCodeRepositories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListCodeRepositories)
+    [Paginator.ListCodeRepositories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListCodeRepositories)
     """
 
     def paginate(
@@ -253,13 +257,13 @@ class ListCodeRepositoriesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListCodeRepositoriesOutputTypeDef]:
         """
-        [ListCodeRepositories.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListCodeRepositories.paginate)
+        [ListCodeRepositories.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListCodeRepositories.paginate)
         """
 
 
 class ListCompilationJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListCompilationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListCompilationJobs)
+    [Paginator.ListCompilationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListCompilationJobs)
     """
 
     def paginate(
@@ -277,26 +281,26 @@ class ListCompilationJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListCompilationJobsResponseTypeDef]:
         """
-        [ListCompilationJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListCompilationJobs.paginate)
+        [ListCompilationJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListCompilationJobs.paginate)
         """
 
 
 class ListDomainsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListDomains)
+    [Paginator.ListDomains documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListDomains)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDomainsResponseTypeDef]:
         """
-        [ListDomains.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListDomains.paginate)
+        [ListDomains.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListDomains.paginate)
         """
 
 
 class ListEndpointConfigsPaginator(Boto3Paginator):
     """
-    [Paginator.ListEndpointConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListEndpointConfigs)
+    [Paginator.ListEndpointConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListEndpointConfigs)
     """
 
     def paginate(
@@ -309,13 +313,13 @@ class ListEndpointConfigsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListEndpointConfigsOutputTypeDef]:
         """
-        [ListEndpointConfigs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListEndpointConfigs.paginate)
+        [ListEndpointConfigs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListEndpointConfigs.paginate)
         """
 
 
 class ListEndpointsPaginator(Boto3Paginator):
     """
-    [Paginator.ListEndpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListEndpoints)
+    [Paginator.ListEndpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListEndpoints)
     """
 
     def paginate(
@@ -340,13 +344,13 @@ class ListEndpointsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListEndpointsOutputTypeDef]:
         """
-        [ListEndpoints.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListEndpoints.paginate)
+        [ListEndpoints.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListEndpoints.paginate)
         """
 
 
 class ListExperimentsPaginator(Boto3Paginator):
     """
-    [Paginator.ListExperiments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListExperiments)
+    [Paginator.ListExperiments documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListExperiments)
     """
 
     def paginate(
@@ -358,13 +362,13 @@ class ListExperimentsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListExperimentsResponseTypeDef]:
         """
-        [ListExperiments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListExperiments.paginate)
+        [ListExperiments.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListExperiments.paginate)
         """
 
 
 class ListFlowDefinitionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListFlowDefinitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListFlowDefinitions)
+    [Paginator.ListFlowDefinitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListFlowDefinitions)
     """
 
     def paginate(
@@ -375,13 +379,13 @@ class ListFlowDefinitionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListFlowDefinitionsResponseTypeDef]:
         """
-        [ListFlowDefinitions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListFlowDefinitions.paginate)
+        [ListFlowDefinitions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListFlowDefinitions.paginate)
         """
 
 
 class ListHumanTaskUisPaginator(Boto3Paginator):
     """
-    [Paginator.ListHumanTaskUis documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListHumanTaskUis)
+    [Paginator.ListHumanTaskUis documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListHumanTaskUis)
     """
 
     def paginate(
@@ -392,13 +396,13 @@ class ListHumanTaskUisPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListHumanTaskUisResponseTypeDef]:
         """
-        [ListHumanTaskUis.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListHumanTaskUis.paginate)
+        [ListHumanTaskUis.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListHumanTaskUis.paginate)
         """
 
 
 class ListHyperParameterTuningJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListHyperParameterTuningJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListHyperParameterTuningJobs)
+    [Paginator.ListHyperParameterTuningJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListHyperParameterTuningJobs)
     """
 
     def paginate(
@@ -414,13 +418,13 @@ class ListHyperParameterTuningJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListHyperParameterTuningJobsResponseTypeDef]:
         """
-        [ListHyperParameterTuningJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListHyperParameterTuningJobs.paginate)
+        [ListHyperParameterTuningJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListHyperParameterTuningJobs.paginate)
         """
 
 
 class ListLabelingJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListLabelingJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListLabelingJobs)
+    [Paginator.ListLabelingJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListLabelingJobs)
     """
 
     def paginate(
@@ -436,13 +440,13 @@ class ListLabelingJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListLabelingJobsResponseTypeDef]:
         """
-        [ListLabelingJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListLabelingJobs.paginate)
+        [ListLabelingJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListLabelingJobs.paginate)
         """
 
 
 class ListLabelingJobsForWorkteamPaginator(Boto3Paginator):
     """
-    [Paginator.ListLabelingJobsForWorkteam documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListLabelingJobsForWorkteam)
+    [Paginator.ListLabelingJobsForWorkteam documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListLabelingJobsForWorkteam)
     """
 
     def paginate(
@@ -456,13 +460,13 @@ class ListLabelingJobsForWorkteamPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListLabelingJobsForWorkteamResponseTypeDef]:
         """
-        [ListLabelingJobsForWorkteam.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListLabelingJobsForWorkteam.paginate)
+        [ListLabelingJobsForWorkteam.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListLabelingJobsForWorkteam.paginate)
         """
 
 
 class ListModelPackagesPaginator(Boto3Paginator):
     """
-    [Paginator.ListModelPackages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListModelPackages)
+    [Paginator.ListModelPackages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListModelPackages)
     """
 
     def paginate(
@@ -475,13 +479,13 @@ class ListModelPackagesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListModelPackagesOutputTypeDef]:
         """
-        [ListModelPackages.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListModelPackages.paginate)
+        [ListModelPackages.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListModelPackages.paginate)
         """
 
 
 class ListModelsPaginator(Boto3Paginator):
     """
-    [Paginator.ListModels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListModels)
+    [Paginator.ListModels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListModels)
     """
 
     def paginate(
@@ -494,13 +498,13 @@ class ListModelsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListModelsOutputTypeDef]:
         """
-        [ListModels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListModels.paginate)
+        [ListModels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListModels.paginate)
         """
 
 
 class ListMonitoringExecutionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListMonitoringExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListMonitoringExecutions)
+    [Paginator.ListMonitoringExecutions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListMonitoringExecutions)
     """
 
     def paginate(
@@ -527,13 +531,13 @@ class ListMonitoringExecutionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListMonitoringExecutionsResponseTypeDef]:
         """
-        [ListMonitoringExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListMonitoringExecutions.paginate)
+        [ListMonitoringExecutions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListMonitoringExecutions.paginate)
         """
 
 
 class ListMonitoringSchedulesPaginator(Boto3Paginator):
     """
-    [Paginator.ListMonitoringSchedules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListMonitoringSchedules)
+    [Paginator.ListMonitoringSchedules documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListMonitoringSchedules)
     """
 
     def paginate(
@@ -550,13 +554,13 @@ class ListMonitoringSchedulesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListMonitoringSchedulesResponseTypeDef]:
         """
-        [ListMonitoringSchedules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListMonitoringSchedules.paginate)
+        [ListMonitoringSchedules.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListMonitoringSchedules.paginate)
         """
 
 
 class ListNotebookInstanceLifecycleConfigsPaginator(Boto3Paginator):
     """
-    [Paginator.ListNotebookInstanceLifecycleConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListNotebookInstanceLifecycleConfigs)
+    [Paginator.ListNotebookInstanceLifecycleConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListNotebookInstanceLifecycleConfigs)
     """
 
     def paginate(
@@ -571,13 +575,13 @@ class ListNotebookInstanceLifecycleConfigsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListNotebookInstanceLifecycleConfigsOutputTypeDef]:
         """
-        [ListNotebookInstanceLifecycleConfigs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListNotebookInstanceLifecycleConfigs.paginate)
+        [ListNotebookInstanceLifecycleConfigs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListNotebookInstanceLifecycleConfigs.paginate)
         """
 
 
 class ListNotebookInstancesPaginator(Boto3Paginator):
     """
-    [Paginator.ListNotebookInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListNotebookInstances)
+    [Paginator.ListNotebookInstances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListNotebookInstances)
     """
 
     def paginate(
@@ -598,13 +602,13 @@ class ListNotebookInstancesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListNotebookInstancesOutputTypeDef]:
         """
-        [ListNotebookInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListNotebookInstances.paginate)
+        [ListNotebookInstances.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListNotebookInstances.paginate)
         """
 
 
 class ListProcessingJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListProcessingJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListProcessingJobs)
+    [Paginator.ListProcessingJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListProcessingJobs)
     """
 
     def paginate(
@@ -620,39 +624,39 @@ class ListProcessingJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListProcessingJobsResponseTypeDef]:
         """
-        [ListProcessingJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListProcessingJobs.paginate)
+        [ListProcessingJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListProcessingJobs.paginate)
         """
 
 
 class ListSubscribedWorkteamsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSubscribedWorkteams documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListSubscribedWorkteams)
+    [Paginator.ListSubscribedWorkteams documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListSubscribedWorkteams)
     """
 
     def paginate(
         self, NameContains: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListSubscribedWorkteamsResponseTypeDef]:
         """
-        [ListSubscribedWorkteams.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListSubscribedWorkteams.paginate)
+        [ListSubscribedWorkteams.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListSubscribedWorkteams.paginate)
         """
 
 
 class ListTagsPaginator(Boto3Paginator):
     """
-    [Paginator.ListTags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListTags)
+    [Paginator.ListTags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListTags)
     """
 
     def paginate(
         self, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListTagsOutputTypeDef]:
         """
-        [ListTags.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListTags.paginate)
+        [ListTags.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListTags.paginate)
         """
 
 
 class ListTrainingJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListTrainingJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListTrainingJobs)
+    [Paginator.ListTrainingJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListTrainingJobs)
     """
 
     def paginate(
@@ -668,13 +672,13 @@ class ListTrainingJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListTrainingJobsResponseTypeDef]:
         """
-        [ListTrainingJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListTrainingJobs.paginate)
+        [ListTrainingJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListTrainingJobs.paginate)
         """
 
 
 class ListTrainingJobsForHyperParameterTuningJobPaginator(Boto3Paginator):
     """
-    [Paginator.ListTrainingJobsForHyperParameterTuningJob documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListTrainingJobsForHyperParameterTuningJob)
+    [Paginator.ListTrainingJobsForHyperParameterTuningJob documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListTrainingJobsForHyperParameterTuningJob)
     """
 
     def paginate(
@@ -686,13 +690,13 @@ class ListTrainingJobsForHyperParameterTuningJobPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListTrainingJobsForHyperParameterTuningJobResponseTypeDef]:
         """
-        [ListTrainingJobsForHyperParameterTuningJob.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListTrainingJobsForHyperParameterTuningJob.paginate)
+        [ListTrainingJobsForHyperParameterTuningJob.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListTrainingJobsForHyperParameterTuningJob.paginate)
         """
 
 
 class ListTransformJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListTransformJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListTransformJobs)
+    [Paginator.ListTransformJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListTransformJobs)
     """
 
     def paginate(
@@ -708,13 +712,13 @@ class ListTransformJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListTransformJobsResponseTypeDef]:
         """
-        [ListTransformJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListTransformJobs.paginate)
+        [ListTransformJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListTransformJobs.paginate)
         """
 
 
 class ListTrialComponentsPaginator(Boto3Paginator):
     """
-    [Paginator.ListTrialComponents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListTrialComponents)
+    [Paginator.ListTrialComponents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListTrialComponents)
     """
 
     def paginate(
@@ -729,13 +733,13 @@ class ListTrialComponentsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListTrialComponentsResponseTypeDef]:
         """
-        [ListTrialComponents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListTrialComponents.paginate)
+        [ListTrialComponents.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListTrialComponents.paginate)
         """
 
 
 class ListTrialsPaginator(Boto3Paginator):
     """
-    [Paginator.ListTrials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListTrials)
+    [Paginator.ListTrials documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListTrials)
     """
 
     def paginate(
@@ -749,13 +753,13 @@ class ListTrialsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListTrialsResponseTypeDef]:
         """
-        [ListTrials.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListTrials.paginate)
+        [ListTrials.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListTrials.paginate)
         """
 
 
 class ListUserProfilesPaginator(Boto3Paginator):
     """
-    [Paginator.ListUserProfiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListUserProfiles)
+    [Paginator.ListUserProfiles documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListUserProfiles)
     """
 
     def paginate(
@@ -767,13 +771,13 @@ class ListUserProfilesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListUserProfilesResponseTypeDef]:
         """
-        [ListUserProfiles.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListUserProfiles.paginate)
+        [ListUserProfiles.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListUserProfiles.paginate)
         """
 
 
 class ListWorkteamsPaginator(Boto3Paginator):
     """
-    [Paginator.ListWorkteams documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListWorkteams)
+    [Paginator.ListWorkteams documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListWorkteams)
     """
 
     def paginate(
@@ -784,13 +788,13 @@ class ListWorkteamsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListWorkteamsResponseTypeDef]:
         """
-        [ListWorkteams.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.ListWorkteams.paginate)
+        [ListWorkteams.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.ListWorkteams.paginate)
         """
 
 
 class SearchPaginator(Boto3Paginator):
     """
-    [Paginator.Search documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.Search)
+    [Paginator.Search documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.Search)
     """
 
     def paginate(
@@ -798,11 +802,11 @@ class SearchPaginator(Boto3Paginator):
         Resource: Literal[
             "TrainingJob", "Experiment", "ExperimentTrial", "ExperimentTrialComponent"
         ],
-        SearchExpression: SearchExpressionTypeDef = None,
+        SearchExpression: "SearchExpressionTypeDef" = None,
         SortBy: str = None,
         SortOrder: Literal["Ascending", "Descending"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[SearchResponseTypeDef]:
         """
-        [Search.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/sagemaker.html#SageMaker.Paginator.Search.paginate)
+        [Search.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/sagemaker.html#SageMaker.Paginator.Search.paginate)
         """
